"""
Lightweight Python Build Tool
"""

__authors__ = ['Raghunandan Rao', "Calum J. Eadie"]
__license__ = "MIT License"
__contact__ = "https://github.com/rags/pynt"
from ._pynt import task, main

__all__ = ["task",  "main"]